@@ -7,9 +7,14 @@
 from functools import partial
 from itertools import chain
 
-import astroid
-from astroid import MANAGER, BoundMethod, arguments, extract_node, helpers, objects
+from astroid import BoundMethod, arguments, extract_node, helpers, objects
+from astroid.exceptions import InferenceError, UseInferenceDefault
+from astroid.inference_tip import inference_tip
 from astroid.interpreter import objectmodel
+from astroid.manager import AstroidManager
+from astroid.node_classes import AssignName, Attribute, Call, Name
+from astroid.scoped_nodes import FunctionDef
+from astroid.util import Uninferable
 
 LRU_CACHE = "functools.lru_cache"
 
@@ -60,23 +65,21 @@ def _functools_partial_inference(node, context=None):
     call = arguments.CallSite.from_call(node, context=context)
     number_of_positional = len(call.positional_arguments)
     if number_of_positional < 1:
-        raise astroid.UseInferenceDefault(
-            "functools.partial takes at least one argument"
-        )
+        raise UseInferenceDefault("functools.partial takes at least one argument")
     if number_of_positional == 1 and not call.keyword_arguments:
-        raise astroid.UseInferenceDefault(
+        raise UseInferenceDefault(
             "functools.partial needs at least to have some filled arguments"
         )
 
     partial_function = call.positional_arguments[0]
     try:
         inferred_wrapped_function = next(partial_function.infer(context=context))
-    except astroid.InferenceError as exc:
-        raise astroid.UseInferenceDefault from exc
-    if inferred_wrapped_function is astroid.Uninferable:
-        raise astroid.UseInferenceDefault("Cannot infer the wrapped function")
-    if not isinstance(inferred_wrapped_function, astroid.FunctionDef):
-        raise astroid.UseInferenceDefault("The wrapped function is not a function")
+    except (InferenceError, StopIteration) as exc:
+        raise UseInferenceDefault from exc
+    if inferred_wrapped_function is Uninferable:
+        raise UseInferenceDefault("Cannot infer the wrapped function")
+    if not isinstance(inferred_wrapped_function, FunctionDef):
+        raise UseInferenceDefault("The wrapped function is not a function")
 
     # Determine if the passed keywords into the callsite are supported
     # by the wrapped function.
@@ -89,14 +92,10 @@ def _functools_partial_inference(node, context=None):
             inferred_wrapped_function.args.kwonlyargs or (),
         )
     parameter_names = {
-        param.name
-        for param in function_parameters
-        if isinstance(param, astroid.AssignName)
+        param.name for param in function_parameters if isinstance(param, AssignName)
     }
     if set(call.keyword_arguments) - parameter_names:
-        raise astroid.UseInferenceDefault(
-            "wrapped function received unknown parameters"
-        )
+        raise UseInferenceDefault("wrapped function received unknown parameters")
 
     partial_function = objects.PartialFunction(
         call,
@@ -122,7 +121,7 @@ def _looks_like_lru_cache(node):
     if not node.decorators:
         return False
     for decorator in node.decorators.nodes:
-        if not isinstance(decorator, astroid.Call):
+        if not isinstance(decorator, Call):
             continue
         if _looks_like_functools_member(decorator, "lru_cache"):
             return True
@@ -131,12 +130,12 @@ def _looks_like_lru_cache(node):
 
 def _looks_like_functools_member(node, member) -> bool:
     """Check if the given Call node is a functools.partial call"""
-    if isinstance(node.func, astroid.Name):
+    if isinstance(node.func, Name):
         return node.func.name == member
-    if isinstance(node.func, astroid.Attribute):
+    if isinstance(node.func, Attribute):
         return (
             node.func.attrname == member
-            and isinstance(node.func.expr, astroid.Name)
+            and isinstance(node.func.expr, Name)
             and node.func.expr.name == "functools"
         )
     return False
@@ -145,13 +144,13 @@ def _looks_like_functools_member(node, member) -> bool:
 _looks_like_partial = partial(_looks_like_functools_member, member="partial")
 
 
-MANAGER.register_transform(
-    astroid.FunctionDef, _transform_lru_cache, _looks_like_lru_cache
+AstroidManager().register_transform(
+    FunctionDef, _transform_lru_cache, _looks_like_lru_cache
 )
 
 
-MANAGER.register_transform(
-    astroid.Call,
-    astroid.inference_tip(_functools_partial_inference),
+AstroidManager().register_transform(
+    Call,
+    inference_tip(_functools_partial_inference),
     _looks_like_partial,
 )
