@@ -14,8 +14,10 @@
 # Copyright (c) 2019 Ashley Whetter <ashley@awhetter.co.uk>
 # Copyright (c) 2020 hippo91 <guillaume.peillex@gmail.com>
 # Copyright (c) 2020 Ram Rachum <ram@rachum.com>
-# Copyright (c) 2021 Marc Mueller <30130371+cdce8p@users.noreply.github.com>
 # Copyright (c) 2021 Pierre Sassoulas <pierre.sassoulas@gmail.com>
+# Copyright (c) 2021 Andrew Haigh <hello@nelf.in>
+# Copyright (c) 2021 pre-commit-ci[bot] <bot@noreply.github.com>
+# Copyright (c) 2021 Marc Mueller <30130371+cdce8p@users.noreply.github.com>
 
 # Licensed under the LGPL: https://www.gnu.org/licenses/old-licenses/lgpl-2.1.en.html
 # For details: https://github.com/PyCQA/astroid/blob/master/LICENSE
@@ -26,17 +28,15 @@ import functools
 import keyword
 from textwrap import dedent
 
-from astroid import (
-    MANAGER,
+from astroid import arguments, inference_tip, nodes, util
+from astroid.builder import AstroidBuilder, extract_node
+from astroid.exceptions import (
+    AstroidTypeError,
+    AstroidValueError,
     InferenceError,
     UseInferenceDefault,
-    arguments,
-    exceptions,
-    inference_tip,
-    nodes,
-    util,
 )
-from astroid.builder import AstroidBuilder, extract_node
+from astroid.manager import AstroidManager
 
 TYPING_NAMEDTUPLE_BASENAMES = {"NamedTuple", "typing.NamedTuple"}
 ENUM_BASE_NAMES = {
@@ -54,11 +54,11 @@ def _infer_first(node, context):
         raise UseInferenceDefault
     try:
         value = next(node.infer(context=context))
-        if value is util.Uninferable:
-            raise UseInferenceDefault()
-        return value
     except StopIteration as exc:
         raise InferenceError from exc
+    if value is util.Uninferable:
+        raise UseInferenceDefault()
+    return value
 
 
 def _find_func_form_arguments(node, context):
@@ -85,7 +85,7 @@ def _find_func_form_arguments(node, context):
 
 
 def infer_func_form(node, base_type, context=None, enum=False):
-    """Specific inference function for namedtuple or Python 3 enum. """
+    """Specific inference function for namedtuple or Python 3 enum."""
     # node is a Call node, class name as first argument and generated class
     # attributes as second argument
 
@@ -127,9 +127,14 @@ def infer_func_form(node, base_type, context=None, enum=False):
                     raise AttributeError from exc
                 if not attributes:
                     raise AttributeError from exc
-    except (AttributeError, exceptions.InferenceError) as exc:
+    except (AttributeError, InferenceError) as exc:
         raise UseInferenceDefault from exc
 
+    if not enum:
+        # namedtuple maps sys.intern(str()) over over field_names
+        attributes = [str(attr) for attr in attributes]
+        # XXX this should succeed *unless* __str__/__repr__ is incorrect or throws
+        # in which case we should not have inferred these values and raised earlier
     attributes = [attr for attr in attributes if " " not in attr]
 
     # If we can't infer the name of the class, don't crash, up to this point
@@ -179,14 +184,23 @@ def infer_named_tuple(node, context=None):
         node, tuple_base_name, context=context
     )
     call_site = arguments.CallSite.from_call(node, context=context)
-    func = next(extract_node("import collections; collections.namedtuple").infer())
+    node = extract_node("import collections; collections.namedtuple")
+    try:
+
+        func = next(node.infer())
+    except StopIteration as e:
+        raise InferenceError(node=node) from e
     try:
         rename = next(call_site.infer_argument(func, "rename", context)).bool_value()
-    except InferenceError:
+    except (InferenceError, StopIteration):
         rename = False
 
-    if rename:
-        attributes = _get_renamed_namedtuple_attributes(attributes)
+    try:
+        attributes = _check_namedtuple_attributes(name, attributes, rename)
+    except AstroidTypeError as exc:
+        raise UseInferenceDefault("TypeError: " + str(exc)) from exc
+    except AstroidValueError as exc:
+        raise UseInferenceDefault("ValueError: " + str(exc)) from exc
 
     replace_args = ", ".join(f"{arg}=None" for arg in attributes)
     field_def = (
@@ -197,7 +211,7 @@ def infer_named_tuple(node, context=None):
         field_def.format(name=name, index=index)
         for index, name in enumerate(attributes)
     )
-    fake = AstroidBuilder(MANAGER).string_build(
+    fake = AstroidBuilder(AstroidManager()).string_build(
         """
 class %(name)s(tuple):
     __slots__ = ()
@@ -247,8 +261,41 @@ def _get_renamed_namedtuple_attributes(field_names):
     return tuple(names)
 
 
+def _check_namedtuple_attributes(typename, attributes, rename=False):
+    attributes = tuple(attributes)
+    if rename:
+        attributes = _get_renamed_namedtuple_attributes(attributes)
+
+    # The following snippet is derived from the CPython Lib/collections/__init__.py sources
+    # <snippet>
+    for name in (typename,) + attributes:
+        if not isinstance(name, str):
+            raise AstroidTypeError("Type names and field names must be strings")
+        if not name.isidentifier():
+            raise AstroidValueError(
+                "Type names and field names must be valid" + f"identifiers: {name!r}"
+            )
+        if keyword.iskeyword(name):
+            raise AstroidValueError(
+                f"Type names and field names cannot be a keyword: {name!r}"
+            )
+
+    seen = set()
+    for name in attributes:
+        if name.startswith("_") and not rename:
+            raise AstroidValueError(
+                f"Field names cannot start with an underscore: {name!r}"
+            )
+        if name in seen:
+            raise AstroidValueError(f"Encountered duplicate field name: {name!r}")
+        seen.add(name)
+    # </snippet>
+
+    return attributes
+
+
 def infer_enum(node, context=None):
-    """ Specific inference function for enum Call node. """
+    """Specific inference function for enum Call node."""
     enum_meta = extract_node(
         """
     class EnumMeta(object):
@@ -306,7 +353,7 @@ INT_FLAG_ADDITION_METHODS = """
 
 
 def infer_enum_class(node):
-    """ Specific inference for enums. """
+    """Specific inference for enums."""
     for basename in node.basenames:
         # TODO: doesn't handle subclasses yet. This implementation
         # is a hack to support enums.
@@ -315,6 +362,8 @@ def infer_enum_class(node):
         if node.root().name == "enum":
             # Skip if the class is directly from enum module.
             break
+        dunder_members = {}
+        target_names = set()
         for local, values in node.locals.items():
             if any(not isinstance(value, nodes.AssignName) for value in values):
                 continue
@@ -344,6 +393,7 @@ def infer_enum_class(node):
             for target in targets:
                 if isinstance(target, nodes.Starred):
                     continue
+                target_names.add(target.name)
                 # Replace all the assignments with our mocked class.
                 classdef = dedent(
                     """
@@ -367,12 +417,46 @@ def infer_enum_class(node):
                     # should result in some nice symbolic execution
                     classdef += INT_FLAG_ADDITION_METHODS.format(name=target.name)
 
-                fake = AstroidBuilder(MANAGER).string_build(classdef)[target.name]
+                fake = AstroidBuilder(AstroidManager()).string_build(classdef)[
+                    target.name
+                ]
                 fake.parent = target.parent
                 for method in node.mymethods():
                     fake.locals[method.name] = [method]
                 new_targets.append(fake.instantiate_class())
+                dunder_members[local] = fake
             node.locals[local] = new_targets
+        members = nodes.Dict(parent=node)
+        members.postinit(
+            [
+                (nodes.Const(k, parent=members), nodes.Name(v.name, parent=members))
+                for k, v in dunder_members.items()
+            ]
+        )
+        node.locals["__members__"] = [members]
+        # The enum.Enum class itself defines two @DynamicClassAttribute data-descriptors
+        # "name" and "value" (which we override in the mocked class for each enum member
+        # above). When dealing with inference of an arbitrary instance of the enum
+        # class, e.g. in a method defined in the class body like:
+        #     class SomeEnum(enum.Enum):
+        #         def method(self):
+        #             self.name  # <- here
+        # In the absence of an enum member called "name" or "value", these attributes
+        # should resolve to the descriptor on that particular instance, i.e. enum member.
+        # For "value", we have no idea what that should be, but for "name", we at least
+        # know that it should be a string, so infer that as a guess.
+        if "name" not in target_names:
+            code = dedent(
+                """
+            @property
+            def name(self):
+                return ''
+            """
+            )
+            name_dynamicclassattr = AstroidBuilder(AstroidManager()).string_build(code)[
+                "name"
+            ]
+            node.locals["name"] = [name_dynamicclassattr]
         break
     return node
 
@@ -392,7 +476,10 @@ def infer_typing_namedtuple_class(class_node, context=None):
     """
     ).format(typename=class_node.name, fields=",".join(annassigns_fields))
     node = extract_node(code)
-    generated_class_node = next(infer_named_tuple(node, context))
+    try:
+        generated_class_node = next(infer_named_tuple(node, context))
+    except StopIteration as e:
+        raise InferenceError(node=node, context=context) from e
     for method in class_node.mymethods():
         generated_class_node.locals[method.name] = [method]
 
@@ -428,7 +515,7 @@ def infer_typing_namedtuple(node, context=None):
     # so we extract the args and infer a named tuple.
     try:
         func = next(node.func.infer())
-    except InferenceError as exc:
+    except (InferenceError, StopIteration) as exc:
         raise UseInferenceDefault from exc
 
     if func.qname() != "typing.NamedTuple":
@@ -457,26 +544,28 @@ def infer_typing_namedtuple(node, context=None):
     return infer_named_tuple(node, context)
 
 
-MANAGER.register_transform(
+AstroidManager().register_transform(
     nodes.Call, inference_tip(infer_named_tuple), _looks_like_namedtuple
 )
-MANAGER.register_transform(nodes.Call, inference_tip(infer_enum), _looks_like_enum)
-MANAGER.register_transform(
+AstroidManager().register_transform(
+    nodes.Call, inference_tip(infer_enum), _looks_like_enum
+)
+AstroidManager().register_transform(
     nodes.ClassDef,
     infer_enum_class,
     predicate=lambda cls: any(
         basename for basename in cls.basenames if basename in ENUM_BASE_NAMES
     ),
 )
-MANAGER.register_transform(
+AstroidManager().register_transform(
     nodes.ClassDef, inference_tip(infer_typing_namedtuple_class), _has_namedtuple_base
 )
-MANAGER.register_transform(
+AstroidManager().register_transform(
     nodes.FunctionDef,
     inference_tip(infer_typing_namedtuple_function),
     lambda node: node.name == "NamedTuple"
     and getattr(node.root(), "name", None) == "typing",
 )
-MANAGER.register_transform(
+AstroidManager().register_transform(
     nodes.Call, inference_tip(infer_typing_namedtuple), _looks_like_typing_namedtuple
 )
