@@ -1,14 +1,19 @@
-# Copyright (c) 2015-2016, 2018 Claudiu Popa <pcmanticore@gmail.com>
+# Copyright (c) 2015-2016, 2018, 2020 Claudiu Popa <pcmanticore@gmail.com>
 # Copyright (c) 2015-2016 Ceridwen <ceridwenv@gmail.com>
 # Copyright (c) 2015 Florian Bruhin <me@the-compiler.org>
 # Copyright (c) 2016 Derek Gustafson <degustaf@gmail.com>
 # Copyright (c) 2018 Nick Drozd <nicholasdrozd@gmail.com>
+# Copyright (c) 2018 Tomas Gavenciak <gavento@ucw.cz>
 # Copyright (c) 2018 Ashley Whetter <ashley@awhetter.co.uk>
 # Copyright (c) 2018 HoverHell <hoverhell@gmail.com>
 # Copyright (c) 2018 Bryce Guinta <bryce.paul.guinta@gmail.com>
+# Copyright (c) 2020-2021 hippo91 <guillaume.peillex@gmail.com>
+# Copyright (c) 2020 Ram Rachum <ram@rachum.com>
+# Copyright (c) 2021 Pierre Sassoulas <pierre.sassoulas@gmail.com>
+# Copyright (c) 2021 Marc Mueller <30130371+cdce8p@users.noreply.github.com>
 
 # Licensed under the LGPL: https://www.gnu.org/licenses/old-licenses/lgpl-2.1.en.html
-# For details: https://github.com/PyCQA/astroid/blob/master/COPYING.LESSER
+# For details: https://github.com/PyCQA/astroid/blob/master/LICENSE
 
 """ A few useful function/method decorators."""
 
@@ -17,8 +22,8 @@ import functools
 import wrapt
 
 from astroid import context as contextmod
-from astroid import exceptions
 from astroid import util
+from astroid.exceptions import InferenceError
 
 
 @wrapt.decorator
@@ -35,7 +40,7 @@ def cached(func, instance, args, kwargs):
 
 
 class cachedproperty:
-    """ Provides a cached property equivalent to the stacking of
+    """Provides a cached property equivalent to the stacking of
     @cached and @property, but more efficient.
 
     After first usage, the <property_name> becomes part of the object's
@@ -90,49 +95,52 @@ def path_wrapper(func):
 
         yielded = set()
         generator = _func(node, context, **kwargs)
-        try:
-            while True:
+        while True:
+            try:
                 res = next(generator)
-                # unproxy only true instance, not const, tuple, dict...
-                if res.__class__.__name__ == "Instance":
-                    ares = res._proxied
-                else:
-                    ares = res
-                if ares not in yielded:
-                    yield res
-                    yielded.add(ares)
-        except StopIteration as error:
-            if error.args:
-                return error.args[0]
-            return None
+            except StopIteration as error:
+                if error.args:
+                    return error.args[0]
+                return None
+
+            # unproxy only true instance, not const, tuple, dict...
+            if res.__class__.__name__ == "Instance":
+                ares = res._proxied
+            else:
+                ares = res
+            if ares not in yielded:
+                yield res
+                yielded.add(ares)
 
     return wrapped
 
 
 @wrapt.decorator
 def yes_if_nothing_inferred(func, instance, args, kwargs):
-    inferred = False
-    for node in func(*args, **kwargs):
-        inferred = True
-        yield node
-    if not inferred:
+    generator = func(*args, **kwargs)
+
+    try:
+        yield next(generator)
+    except StopIteration:
+        # generator is empty
         yield util.Uninferable
+        return
+
+    yield from generator
 
 
 @wrapt.decorator
 def raise_if_nothing_inferred(func, instance, args, kwargs):
-    inferred = False
+    generator = func(*args, **kwargs)
     try:
-        generator = func(*args, **kwargs)
-        while True:
-            yield next(generator)
-            inferred = True
+        yield next(generator)
     except StopIteration as error:
-        if not inferred:
-            if error.args:
-                # pylint: disable=not-a-mapping
-                raise exceptions.InferenceError(**error.args[0])
-            else:
-                raise exceptions.InferenceError(
-                    "StopIteration raised without any error information."
-                )
+        # generator is empty
+        if error.args:
+            # pylint: disable=not-a-mapping
+            raise InferenceError(**error.args[0]) from error
+        raise InferenceError(
+            "StopIteration raised without any error information."
+        ) from error
+
+    yield from generator
